## pyqt-units
A system of measurements\units for use in pyqt entry boxes and reports

# Usage
These widgets allow the entry and display (view-side) of numbers with a measurement(such as length) to reflect 
a "current unit" which can be varied at will, while leaving all model-side values in SI units.

This means that units don't need to be considered during calculations, storage or data manipulation.

